@@ -240,7 +240,7 @@ class Polysynth:
             _amm_contract_addr = _amm_name_to_addr(amm, self.network)
             _side = _side_str_to_int(side)
             _quote_asset_limit = self._quote_asset_limit(amm, quoteAssetAmount, leverage, _side, slippage)
-            _size = _normalize(self._input_price(amm, side, quoteAssetAmount)[0])
+            _size = _normalize(self._input_price(amm, side, quoteAssetAmount*leverage)[0])
             _price = (quoteAssetAmount*leverage)/_size
 
             manager = self.manager_contract.functions
